@@ -1194,10 +1194,11 @@ account_widget_build_external (EmpathyAccountWidget *self,
   else if (!tp_strdiff (provider, "org.gnome.OnlineAccounts"))
     {
       /* FIXME: we should publish the .desktop file in some general way */
-      desktop_info = g_desktop_app_info_new ("goa-prefs.desktop");
+      desktop_info = g_desktop_app_info_new (
+          "gnome-online-accounts-panel.desktop");
 
       if (desktop_info == NULL)
-        g_critical ("Could not locate 'goa-prefs.desktop'");
+        g_critical ("Could not locate 'gnome-online-accounts-panel.desktop'");
       else
         name = g_app_info_get_name (G_APP_INFO (desktop_info));
     }
@@ -2363,7 +2364,7 @@ empathy_account_widget_class_init (EmpathyAccountWidgetClass *klass)
   signals[HANDLE_APPLY] =
     g_signal_new ("handle-apply", G_TYPE_FROM_CLASS (klass),
         G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-        g_cclosure_marshal_VOID__BOOLEAN,
+        g_cclosure_marshal_generic,
         G_TYPE_NONE,
         1, G_TYPE_BOOLEAN);
 
@@ -2371,14 +2372,14 @@ empathy_account_widget_class_init (EmpathyAccountWidgetClass *klass)
   signals[ACCOUNT_CREATED] =
       g_signal_new ("account-created", G_TYPE_FROM_CLASS (klass),
           G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-          g_cclosure_marshal_VOID__OBJECT,
+          g_cclosure_marshal_generic,
           G_TYPE_NONE,
           1, G_TYPE_OBJECT);
 
   signals[CANCELLED] =
       g_signal_new ("cancelled", G_TYPE_FROM_CLASS (klass),
           G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-          g_cclosure_marshal_VOID__VOID,
+          g_cclosure_marshal_generic,
           G_TYPE_NONE,
           0);
 
