@@ -70,9 +70,9 @@ typedef struct {
 	guint                       setup_idle_id;
 	gboolean                    dispose_has_run;
 	GHashTable                  *status_icons;
-	/* Hash: EmpathyContact* -> GQueue (GtkTreeRowReference) */
+	/* Hash: EmpathyContact* -> GQueue (GtkTreeIter *) */
 	GHashTable                  *empathy_contact_cache;
-	/* Hash: char *groupname -> GtkTreeRowReference *row */
+	/* Hash: char *groupname -> GtkTreeIter * */
 	GHashTable                  *empathy_group_cache;
 } EmpathyContactListStorePriv;
 
@@ -80,6 +80,7 @@ typedef struct {
 	EmpathyContactListStore *store;
 	EmpathyContact          *contact;
 	gboolean                remove;
+	guint                   timeout;
 } ShowActiveData;
 
 static void             contact_list_store_dispose                  (GObject                       *object);
@@ -100,10 +101,6 @@ static void             contact_list_store_members_changed_cb        (EmpathyCon
 								      gchar                         *message,
 								      gboolean                       is_member,
 								      EmpathyContactListStore       *store);
-static void             contact_list_store_favourites_changed_cb     (EmpathyContactList            *list_iface,
-								      EmpathyContact                *contact,
-								      gboolean                       is_favourite,
-								      EmpathyContactListStore       *store);
 static void             contact_list_store_member_renamed_cb         (EmpathyContactList            *list_iface,
 								      EmpathyContact                *old_contact,
 								      EmpathyContact                *new_contact,
@@ -207,10 +204,6 @@ contact_list_store_iface_setup (gpointer user_data)
 			  "members-changed",
 			  G_CALLBACK (contact_list_store_members_changed_cb),
 			  store);
-	g_signal_connect (priv->list,
-			  "favourites-changed",
-			  G_CALLBACK (contact_list_store_favourites_changed_cb),
-			  store);
 	g_signal_connect (priv->list,
 			  "groups-changed",
 			  G_CALLBACK (contact_list_store_groups_changed_cb),
@@ -322,10 +315,10 @@ empathy_contact_list_store_class_init (EmpathyContactListStoreClass *klass)
 }
 
 static void
-g_queue_free_full_row_ref (gpointer data)
+g_queue_free_full_iter (gpointer data)
 {
 	GQueue *queue = (GQueue *) data;
-	g_queue_foreach (queue, (GFunc) gtk_tree_row_reference_free, NULL);
+	g_queue_foreach (queue, (GFunc) gtk_tree_iter_free, NULL);
 	g_queue_free (queue);
 }
 
@@ -345,10 +338,10 @@ empathy_contact_list_store_init (EmpathyContactListStore *store)
 						      store);
 	priv->status_icons = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
 	priv->empathy_contact_cache = g_hash_table_new_full (NULL, NULL, NULL,
-		g_queue_free_full_row_ref);
+		g_queue_free_full_iter);
 	priv->empathy_group_cache = g_hash_table_new_full (g_str_hash,
 		g_str_equal, g_free,
-		(GDestroyNotify) gtk_tree_row_reference_free);
+		(GDestroyNotify) gtk_tree_iter_free);
 	contact_list_store_setup (store);
 }
 
@@ -378,20 +371,19 @@ contact_list_store_dispose (GObject *object)
 	g_signal_handlers_disconnect_by_func (priv->list,
 					      G_CALLBACK (contact_list_store_members_changed_cb),
 					      object);
-	g_signal_handlers_disconnect_by_func (priv->list,
-					      G_CALLBACK (contact_list_store_favourites_changed_cb),
-					      object);
 	g_signal_handlers_disconnect_by_func (priv->list,
 					      G_CALLBACK (contact_list_store_groups_changed_cb),
 					      object);
 	g_object_unref (priv->list);
 
-	if (priv->inhibit_active) {
+	if (priv->inhibit_active != 0) {
 		g_source_remove (priv->inhibit_active);
+		priv->inhibit_active = 0;
 	}
 
 	if (priv->setup_idle_id != 0) {
 		g_source_remove (priv->setup_idle_id);
+		priv->setup_idle_id = 0;
 	}
 
 	g_hash_table_destroy (priv->status_icons);
@@ -936,21 +928,6 @@ contact_list_store_members_changed_cb (EmpathyContactList      *list_iface,
 	}
 }
 
-static void
-contact_list_store_favourites_changed_cb (EmpathyContactList      *list_iface,
-					  EmpathyContact          *contact,
-					  gboolean                 is_favourite,
-					  EmpathyContactListStore *store)
-{
-	DEBUG ("Contact %s (%d) is %s a favourite",
-		empathy_contact_get_id (contact),
-		empathy_contact_get_handle (contact),
-		is_favourite ? "now" : "no longer");
-
-	contact_list_store_remove_contact (store, contact);
-	contact_list_store_add_contact (store, contact);
-}
-
 static void
 contact_list_store_member_renamed_cb (EmpathyContactList      *list_iface,
 				      EmpathyContact          *old_contact,
@@ -1007,8 +984,6 @@ add_contact_to_store (GtkTreeStore *store,
 		      EmpathyContactListFlags flags)
 {
 	EmpathyContactListStorePriv *priv = GET_PRIV (store);
-	GtkTreeRowReference *row_ref;
-	GtkTreePath *path;
 	GQueue *queue;
 
 	gtk_tree_store_insert_with_values (store, iter, parent, 0,
@@ -1025,18 +1000,15 @@ add_contact_to_store (GtkTreeStore *store,
 			    EMPATHY_CONTACT_LIST_STORE_COL_FLAGS, flags,
 			    -1);
 
-	path = gtk_tree_model_get_path (GTK_TREE_MODEL (store), iter);
-	row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (store), path);
 	queue = g_hash_table_lookup (priv->empathy_contact_cache, contact);
 	if (queue) {
-		g_queue_push_tail (queue, row_ref);
+		g_queue_push_tail (queue, gtk_tree_iter_copy (iter));
 	} else {
 		queue = g_queue_new ();
-		g_queue_push_tail (queue, row_ref);
+		g_queue_push_tail (queue, gtk_tree_iter_copy (iter));
 		g_hash_table_insert (priv->empathy_contact_cache, contact,
 			queue);
 	}
-	gtk_tree_path_free (path);
 }
 
 static void
@@ -1076,15 +1048,6 @@ contact_list_store_add_contact (EmpathyContactListStore *store,
 
 		if (!priv->show_groups) {
 			parent = NULL;
-		} else if (!tp_strdiff (protocol_name, "local-xmpp")) {
-			/* these are People Nearby */
-			contact_list_store_get_group (store,
-				EMPATHY_CONTACT_LIST_STORE_PEOPLE_NEARBY,
-				&iter_group, NULL, NULL, TRUE);
-		} else {
-			contact_list_store_get_group (store,
-				EMPATHY_CONTACT_LIST_STORE_UNGROUPED,
-				&iter_group, NULL, NULL, TRUE);
 		}
 
 		add_contact_to_store (GTK_TREE_STORE (store), &iter, parent,
@@ -1104,17 +1067,6 @@ contact_list_store_add_contact (EmpathyContactListStore *store,
 	}
 	g_list_free (groups);
 
-	if (priv->show_groups &&
-	    empathy_contact_list_is_favourite (priv->list, contact)) {
-	/* Add contact to the fake 'Favorites' group */
-		GtkTreeIter iter_group;
-
-		contact_list_store_get_group (store, EMPATHY_CONTACT_LIST_STORE_FAVORITE,
-			&iter_group, NULL, NULL, TRUE);
-
-		add_contact_to_store (GTK_TREE_STORE (store), &iter, &iter_group, contact, flags);
-	}
-
 	contact_list_store_contact_update (store, contact);
 }
 
@@ -1136,22 +1088,14 @@ contact_list_store_remove_contact (EmpathyContactListStore *store,
 	model = GTK_TREE_MODEL (store);
 
 	for (l = g_queue_peek_head_link (row_refs); l; l = l->next) {
-		GtkTreePath *path = gtk_tree_row_reference_get_path (l->data);
-		GtkTreeIter iter;
+		GtkTreeIter *iter = l->data;
 		GtkTreeIter parent;
 
-		if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter,
-			path)) {
-			gtk_tree_path_free (path);
-			continue;
-		}
-		gtk_tree_path_free (path);
-
 		/* NOTE: it is only <= 2 here because we have
 		 * separators after the group name, otherwise it
 		 * should be 1.
 		 */
-		if (gtk_tree_model_iter_parent (model, &parent, &iter) &&
+		if (gtk_tree_model_iter_parent (model, &parent, iter) &&
 		    gtk_tree_model_iter_n_children (model, &parent) <= 2) {
 			gchar *group_name;
 			gtk_tree_model_get (model, &parent,
@@ -1161,7 +1105,7 @@ contact_list_store_remove_contact (EmpathyContactListStore *store,
 				group_name);
 			gtk_tree_store_remove (GTK_TREE_STORE (store), &parent);
 		} else {
-			gtk_tree_store_remove (GTK_TREE_STORE (store), &iter);
+			gtk_tree_store_remove (GTK_TREE_STORE (store), iter);
 		}
 	}
 
@@ -1313,7 +1257,7 @@ contact_list_store_contact_update (EmpathyContactListStore *store,
 
 		if (do_set_active) {
 			data = contact_list_store_contact_active_new (store, contact, do_remove);
-			g_timeout_add_seconds (ACTIVE_USER_SHOW_TIME,
+			data->timeout = g_timeout_add_seconds (ACTIVE_USER_SHOW_TIME,
 					       (GSourceFunc) contact_list_store_contact_active_cb,
 					       data);
 		}
@@ -1372,6 +1316,24 @@ contact_list_store_contact_set_active (EmpathyContactListStore *store,
 
 }
 
+static void
+store_contact_active_invalidated (ShowActiveData *data,
+	GObject *old_object)
+{
+	/* Remove the timeout and free the struct, since the contact or contact
+	 * store has disappeared. */
+	g_source_remove (data->timeout);
+
+	 if (old_object == (GObject *) data->store)
+		data->store = NULL;
+	 else if (old_object == (GObject *) data->contact)
+		data->contact = NULL;
+	 else
+		g_assert_not_reached ();
+
+	contact_list_store_contact_active_free (data);
+}
+
 static ShowActiveData *
 contact_list_store_contact_active_new (EmpathyContactListStore *store,
 				       EmpathyContact          *contact,
@@ -1385,9 +1347,18 @@ contact_list_store_contact_active_new (EmpathyContactListStore *store,
 
 	data = g_slice_new0 (ShowActiveData);
 
-	data->store = g_object_ref (store);
-	data->contact = g_object_ref (contact);
+	/* We don't actually want to force either the IndividualStore or the
+	 * Individual to stay alive, since the user could quit Empathy or disable
+	 * the account before the contact_active timeout is fired. */
+	g_object_weak_ref (G_OBJECT (store),
+		(GWeakNotify) store_contact_active_invalidated, data);
+	g_object_weak_ref (G_OBJECT (contact),
+		(GWeakNotify) store_contact_active_invalidated, data);
+
+	data->store = store;
+	data->contact = contact;
 	data->remove = remove_;
+	data->timeout = 0;
 
 	return data;
 }
@@ -1395,8 +1366,13 @@ contact_list_store_contact_active_new (EmpathyContactListStore *store,
 static void
 contact_list_store_contact_active_free (ShowActiveData *data)
 {
-	g_object_unref (data->contact);
-	g_object_unref (data->store);
+	if (data->store != NULL)
+		g_object_weak_unref (G_OBJECT (data->store),
+			(GWeakNotify) store_contact_active_invalidated, data);
+
+	if (data->contact != NULL)
+		g_object_weak_unref (G_OBJECT (data->contact),
+			(GWeakNotify) store_contact_active_invalidated, data);
 
 	g_slice_free (ShowActiveData, data);
 }
@@ -1441,14 +1417,12 @@ contact_list_store_get_group (EmpathyContactListStore *store,
 	GtkTreeModel                *model;
 	GtkTreeIter                  iter_group;
 	GtkTreeIter                  iter_separator;
-	GtkTreeRowReference         *row_ref;
+	GtkTreeIter                 *iter;
 
 	model = GTK_TREE_MODEL (store);
-	row_ref = g_hash_table_lookup (priv->empathy_group_cache, name);
-
-	if (row_ref == NULL) {
-		GtkTreePath *path;
+	iter = g_hash_table_lookup (priv->empathy_group_cache, name);
 
+	if (iter == NULL) {
 		if (created) {
 			*created = TRUE;
 		}
@@ -1462,11 +1436,8 @@ contact_list_store_get_group (EmpathyContactListStore *store,
 				    EMPATHY_CONTACT_LIST_STORE_COL_IS_FAKE_GROUP, is_fake_group,
 				    -1);
 
-		path = gtk_tree_model_get_path (GTK_TREE_MODEL (store), &iter_group);
-		row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (store), path);
 		g_hash_table_insert (priv->empathy_group_cache,
-			g_strdup (name), row_ref);
-		gtk_tree_path_free (path);
+			g_strdup (name), gtk_tree_iter_copy (&iter_group));
 
 		if (iter_group_to_set) {
 			*iter_group_to_set = iter_group;
@@ -1480,24 +1451,15 @@ contact_list_store_get_group (EmpathyContactListStore *store,
 			*iter_separator_to_set = iter_separator;
 		}
 	} else {
-		GtkTreePath *path = gtk_tree_row_reference_get_path (row_ref);
-		GtkTreeIter iter;
-
-		if (!gtk_tree_model_get_iter (model, &iter, path)) {
-			gtk_tree_path_free (path);
-			return;
-		}
-		gtk_tree_path_free (path);
-
 		if (created) {
 			*created = FALSE;
 		}
 
 		if (iter_group_to_set) {
-			*iter_group_to_set = iter;
+			*iter_group_to_set = *iter;
 		}
 
-		iter_separator = iter;
+		iter_separator = *iter;
 
 		if (gtk_tree_model_iter_next (model, &iter_separator)) {
 			gboolean is_separator;
@@ -1513,20 +1475,6 @@ contact_list_store_get_group (EmpathyContactListStore *store,
 	}
 }
 
-static gint
-get_position (const char **strv,
-	      const char *str)
-{
-	int i;
-
-	for (i = 0; strv[i] != NULL; i++) {
-		if (!tp_strdiff (strv[i], str))
-			return i;
-	}
-
-	return -1;
-}
-
 static gint
 compare_separator_and_groups (gboolean is_separator_a,
 			      gboolean is_separator_b,
@@ -1537,18 +1485,6 @@ compare_separator_and_groups (gboolean is_separator_a,
 			      gboolean fake_group_a,
 			      gboolean fake_group_b)
 {
-	/* these two lists are the sorted list of fake groups to include at the
-	 * top and bottom of the roster */
-	const char *top_groups[] = {
-		EMPATHY_CONTACT_LIST_STORE_FAVORITE,
-		NULL
-	};
-
-	const char *bottom_groups[] = {
-		EMPATHY_CONTACT_LIST_STORE_UNGROUPED,
-		NULL
-	};
-
 	if (is_separator_a || is_separator_b) {
 		/* We have at least one separator */
 		if (is_separator_a) {
@@ -1564,34 +1500,7 @@ compare_separator_and_groups (gboolean is_separator_a,
 	} else if (contact_a && !contact_b) {
 		return -1;
 	} else if (!contact_a && !contact_b) {
-		gboolean a_in_top, b_in_top, a_in_bottom, b_in_bottom;
-
-		a_in_top = fake_group_a &&
-			tp_strv_contains (top_groups, name_a);
-		b_in_top = fake_group_b &&
-			tp_strv_contains (top_groups, name_b);
-		a_in_bottom = fake_group_a &&
-			tp_strv_contains (bottom_groups, name_a);
-		b_in_bottom = fake_group_b &&
-			tp_strv_contains (bottom_groups, name_b);
-
-		if (a_in_top && b_in_top) {
-			/* compare positions */
-			return CLAMP (get_position (top_groups, name_a) -
-				      get_position (top_groups, name_b),
-				      -1, 1);
-		} else if (a_in_bottom && b_in_bottom) {
-			/* compare positions */
-			return CLAMP (get_position (bottom_groups, name_a) -
-				      get_position (bottom_groups, name_b),
-				      -1, 1);
-		} else if (a_in_top || b_in_bottom) {
-			return -1;
-		} else if (b_in_top || a_in_bottom) {
-			return 1;
-		} else {
-			return g_utf8_collate (name_a, name_b);
-		}
+		return g_utf8_collate (name_a, name_b);
 	}
 
 	/* Two contacts, ordering depends of the sorting policy */
@@ -1744,27 +1653,20 @@ contact_list_store_find_contact (EmpathyContactListStore *store,
 				 EmpathyContact          *contact)
 {
 	EmpathyContactListStorePriv *priv = GET_PRIV (store);
-	GtkTreeModel              *model;
 	GQueue                    *row_refs_queue;
 	GList                     *i;
 	GList                     *iters_list = NULL;
 
-	model = GTK_TREE_MODEL (store);
 	row_refs_queue = g_hash_table_lookup (priv->empathy_contact_cache, contact);
 	if (!row_refs_queue)
 		return NULL;
 
 	for (i = g_queue_peek_head_link (row_refs_queue) ; i != NULL ;
 	     i = i->next) {
-		GtkTreePath *path = gtk_tree_row_reference_get_path (i->data);
-		GtkTreeIter iter;
-		if (!gtk_tree_model_get_iter (model, &iter, path)) {
-			gtk_tree_path_free (path);
-			continue;
-		}
-		gtk_tree_path_free (path);
+		GtkTreeIter *iter = i->data;
+
 		iters_list = g_list_prepend
-			(iters_list, gtk_tree_iter_copy (&iter));
+			(iters_list, gtk_tree_iter_copy (iter));
 	}
 
 	return iters_list;
