@@ -85,7 +85,7 @@ enum {
 };
 
 G_DEFINE_TYPE (EmpathyIndividualLinker, empathy_individual_linker,
-    GTK_TYPE_BIN);
+    GTK_TYPE_BOX);
 
 static void
 contact_toggle_cell_data_func (GtkTreeViewColumn *tree_column,
@@ -280,7 +280,7 @@ individual_view_drag_motion_cb (GtkWidget *widget,
 
   target = gtk_drag_dest_find_target (GTK_WIDGET (view), context, NULL);
 
-  if (target == gdk_atom_intern_static_string ("text/persona-id"))
+  if (target == gdk_atom_intern_static_string ("text/x-persona-id"))
     {
       GtkTreePath *path;
 
@@ -494,7 +494,7 @@ set_up (EmpathyIndividualLinker *self)
   gtk_box_pack_start (GTK_BOX (top_vbox), label, FALSE, TRUE, 0);
 
   /* Add the main vbox to the bin */
-  gtk_container_add (GTK_CONTAINER (self), GTK_WIDGET (top_vbox));
+  gtk_box_pack_start (GTK_BOX (self), GTK_WIDGET (top_vbox), TRUE, TRUE, 0);
   gtk_widget_show (GTK_WIDGET (top_vbox));
 }
 
@@ -577,46 +577,16 @@ finalize (GObject *object)
   G_OBJECT_CLASS (empathy_individual_linker_parent_class)->finalize (object);
 }
 
-static void
-size_allocate (GtkWidget *widget,
-    GtkAllocation *allocation)
-{
-  GtkBin *bin = GTK_BIN (widget);
-  GtkAllocation child_allocation;
-  GtkWidget *child;
-
-  gtk_widget_set_allocation (widget, allocation);
-
-  child = gtk_bin_get_child (bin);
-
-  if (child && gtk_widget_get_visible (child))
-    {
-      child_allocation.x = allocation->x +
-          gtk_container_get_border_width (GTK_CONTAINER (widget));
-      child_allocation.y = allocation->y +
-          gtk_container_get_border_width (GTK_CONTAINER (widget));
-      child_allocation.width = MAX (allocation->width -
-          gtk_container_get_border_width (GTK_CONTAINER (widget)) * 2, 0);
-      child_allocation.height = MAX (allocation->height -
-          gtk_container_get_border_width (GTK_CONTAINER (widget)) * 2, 0);
-
-      gtk_widget_size_allocate (child, &child_allocation);
-    }
-}
-
 static void
 empathy_individual_linker_class_init (EmpathyIndividualLinkerClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
-  GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   object_class->get_property = get_property;
   object_class->set_property = set_property;
   object_class->dispose = dispose;
   object_class->finalize = finalize;
 
-  widget_class->size_allocate = size_allocate;
-
   /**
    * EmpathyIndividualLinker:start-individual:
    *
