@@ -228,14 +228,14 @@ empathy_camera_monitor_class_init (EmpathyCameraMonitorClass *klass)
       g_signal_new ("added", G_OBJECT_CLASS_TYPE (klass),
           G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
           0, NULL, NULL,
-          g_cclosure_marshal_VOID__BOXED,
+          g_cclosure_marshal_generic,
           G_TYPE_NONE, 1, EMPATHY_TYPE_CAMERA);
 
   signals[CAMERA_REMOVED] =
       g_signal_new ("removed", G_OBJECT_CLASS_TYPE (klass),
           G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
           0, NULL, NULL,
-          g_cclosure_marshal_VOID__BOXED,
+          g_cclosure_marshal_generic,
           G_TYPE_NONE, 1, EMPATHY_TYPE_CAMERA);
 
   g_type_class_add_private (object_class,
