@@ -22,7 +22,6 @@
 #include "config.h"
 
 #include "empathy-contact-list.h"
-#include "empathy-marshal.h"
 
 static void contact_list_base_init (gpointer klass);
 
@@ -59,7 +58,7 @@ contact_list_base_init (gpointer klass)
 			      G_SIGNAL_RUN_LAST,
 			      0,
 			      NULL, NULL,
-			      _empathy_marshal_VOID__OBJECT_OBJECT_UINT_STRING,
+			      g_cclosure_marshal_generic,
 			      G_TYPE_NONE,
 			      4, EMPATHY_TYPE_CONTACT, EMPATHY_TYPE_CONTACT, G_TYPE_UINT, G_TYPE_STRING);
 
@@ -68,26 +67,17 @@ contact_list_base_init (gpointer klass)
 			      G_SIGNAL_RUN_LAST,
 			      0,
 			      NULL, NULL,
-			      _empathy_marshal_VOID__OBJECT_OBJECT_UINT_STRING_BOOLEAN,
+			      g_cclosure_marshal_generic,
 			      G_TYPE_NONE,
 			      5, EMPATHY_TYPE_CONTACT, EMPATHY_TYPE_CONTACT,
 			      G_TYPE_UINT, G_TYPE_STRING, G_TYPE_BOOLEAN);
 
-		g_signal_new ("favourites-changed",
-			      G_TYPE_FROM_CLASS (klass),
-			      G_SIGNAL_RUN_LAST,
-			      0,
-			      NULL, NULL,
-			      _empathy_marshal_VOID__OBJECT_BOOLEAN,
-			      G_TYPE_NONE,
-			      2, EMPATHY_TYPE_CONTACT, G_TYPE_BOOLEAN);
-
 		g_signal_new ("pendings-changed",
 			      G_TYPE_FROM_CLASS (klass),
 			      G_SIGNAL_RUN_LAST,
 			      0,
 			      NULL, NULL,
-			      _empathy_marshal_VOID__OBJECT_OBJECT_UINT_STRING_BOOLEAN,
+			      g_cclosure_marshal_generic,
 			      G_TYPE_NONE,
 			      5, EMPATHY_TYPE_CONTACT, EMPATHY_TYPE_CONTACT,
 			      G_TYPE_UINT, G_TYPE_STRING, G_TYPE_BOOLEAN);
@@ -97,7 +87,7 @@ contact_list_base_init (gpointer klass)
 			      G_SIGNAL_RUN_LAST,
 			      0,
 			      NULL, NULL,
-			      _empathy_marshal_VOID__OBJECT_STRING_BOOLEAN,
+			      g_cclosure_marshal_generic,
 			      G_TYPE_NONE,
 			      3, EMPATHY_TYPE_CONTACT, G_TYPE_STRING, G_TYPE_BOOLEAN);
 
@@ -247,40 +237,26 @@ empathy_contact_list_get_flags (EmpathyContactList *list)
 	}
 }
 
+void
+empathy_contact_list_set_blocked (EmpathyContactList *list,
+				  EmpathyContact     *contact,
+				  gboolean            blocked,
+				  gboolean            abusive)
+{
+	EmpathyContactListIface *iface = EMPATHY_CONTACT_LIST_GET_IFACE (list);
+
+	if (iface->set_blocked != NULL)
+		iface->set_blocked (list, contact, blocked, abusive);
+}
+
 gboolean
-empathy_contact_list_is_favourite (EmpathyContactList *list,
-                                   EmpathyContact     *contact)
+empathy_contact_list_get_blocked (EmpathyContactList *list,
+				  EmpathyContact     *contact)
 {
-#if HAVE_FAVOURITE_CONTACTS
-	if (EMPATHY_CONTACT_LIST_GET_IFACE (list)->is_favourite) {
-		return EMPATHY_CONTACT_LIST_GET_IFACE (list)->is_favourite (
-			list, contact);
-	}
-#endif /* HAVE_FAVOURITE_CONTACTS */
+	EmpathyContactListIface *iface = EMPATHY_CONTACT_LIST_GET_IFACE (list);
 
-	return FALSE;
-}
-
-void
-empathy_contact_list_add_to_favourites (EmpathyContactList *list,
-                                        EmpathyContact     *contact)
-{
-#if HAVE_FAVOURITE_CONTACTS
-	if (EMPATHY_CONTACT_LIST_GET_IFACE (list)->add_favourite) {
-		EMPATHY_CONTACT_LIST_GET_IFACE (list)->add_favourite (list,
-			contact);
-	}
-#endif /* HAVE_FAVOURITE_CONTACTS */
-}
-
-void
-empathy_contact_list_remove_from_favourites (EmpathyContactList *list,
-                                             EmpathyContact     *contact)
-{
-#if HAVE_FAVOURITE_CONTACTS
-	if (EMPATHY_CONTACT_LIST_GET_IFACE (list)->remove_favourite) {
-		EMPATHY_CONTACT_LIST_GET_IFACE (list)->remove_favourite (list,
-			contact);
-	}
-#endif /* HAVE_FAVOURITE_CONTACTS */
+	if (iface->get_blocked != NULL)
+		return iface->get_blocked (list, contact);
+	else
+		return FALSE;
 }
