@@ -275,7 +275,7 @@ tp_roomlist_create_channel_cb (GObject *source,
 	if (priv->channel == NULL) {
 		DEBUG ("Error creating channel: %s", error->message);
 		g_error_free (error);
-		return;
+		goto out;
 	}
 
 	g_signal_connect (priv->channel, "invalidated",
@@ -299,9 +299,12 @@ tp_roomlist_create_channel_cb (GObject *source,
 
 	if (priv->start_requested == TRUE) {
 		tp_cli_channel_type_room_list_call_list_rooms (priv->channel, -1,
-			call_list_rooms_cb, self, NULL, NULL);
+			call_list_rooms_cb, self, NULL, G_OBJECT (self));
 		priv->start_requested = FALSE;
 	}
+
+out:
+	g_object_unref (self);
 }
 
 static void
@@ -348,6 +351,9 @@ tp_roomlist_constructed (GObject *list)
 	req = tp_account_channel_request_new (priv->account, request,
 		TP_USER_ACTION_TIME_CURRENT_TIME);
 
+	/* Ensure we stay alive during the async call */
+	g_object_ref (list);
+
 	tp_account_channel_request_create_and_handle_channel_async (req, NULL,
 		tp_roomlist_create_channel_cb, list);
 
@@ -426,7 +432,7 @@ empathy_tp_roomlist_class_init (EmpathyTpRoomlistClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      0,
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__OBJECT,
+			      g_cclosure_marshal_generic,
 			      G_TYPE_NONE,
 			      1, EMPATHY_TYPE_CHATROOM);
 
@@ -436,7 +442,7 @@ empathy_tp_roomlist_class_init (EmpathyTpRoomlistClass *klass)
 			      G_SIGNAL_RUN_LAST,
 			      0,
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
+			      g_cclosure_marshal_generic,
 			      G_TYPE_NONE,
 			      0);
 
@@ -446,7 +452,7 @@ empathy_tp_roomlist_class_init (EmpathyTpRoomlistClass *klass)
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
 			      0,
 			      NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
+			      g_cclosure_marshal_generic,
 			      G_TYPE_NONE,
 			      1, G_TYPE_POINTER);
 
