@@ -85,30 +85,28 @@ empathy_accounts_has_accounts (TpAccountManager *manager)
 static void
 do_show_accounts_ui (TpAccountManager *manager,
     TpAccount *account,
-    GApplication *app)
+    GCallback window_destroyed_cb)
 {
   static GtkWidget *accounts_window = NULL;
 
   if (accounts_window == NULL)
-    {
-      accounts_window = empathy_accounts_dialog_show (NULL, account);
+    accounts_window = empathy_accounts_dialog_show (NULL, account);
 
-      gtk_application_add_window (GTK_APPLICATION (app),
-          GTK_WINDOW (accounts_window));
-    }
+  if (window_destroyed_cb)
+    g_signal_connect (accounts_window, "destroy", window_destroyed_cb, NULL);
 
   gtk_window_present (GTK_WINDOW (accounts_window));
 }
 
 static GtkWidget *
 show_account_assistant (EmpathyConnectionManagers *connection_mgrs,
-    GApplication *app)
+    GCallback assistant_destroy_cb)
 {
   GtkWidget *assistant;
 
   assistant = empathy_account_assistant_show (NULL, connection_mgrs);
-
-  gtk_application_add_window (GTK_APPLICATION (app), GTK_WINDOW (assistant));
+  if (assistant_destroy_cb)
+    g_signal_connect (assistant, "destroy", assistant_destroy_cb, NULL);
 
   return assistant;
 }
@@ -119,31 +117,31 @@ connection_managers_prepare_for_accounts (GObject *source,
     gpointer user_data)
 {
   EmpathyConnectionManagers *cm_mgr = EMPATHY_CONNECTION_MANAGERS (source);
-  GApplication *app = user_data;
+  GCallback assistant_destroy_cb = G_CALLBACK (user_data);
 
   if (!empathy_connection_managers_prepare_finish (cm_mgr, result, NULL))
     goto out;
 
-  show_account_assistant (cm_mgr, app);
+  show_account_assistant (cm_mgr, assistant_destroy_cb);
   DEBUG ("would show the account assistant");
 
 out:
   g_object_unref (cm_mgr);
-  g_application_release (app);
 }
 
 void
 empathy_accounts_show_accounts_ui (TpAccountManager *manager,
     TpAccount *account,
-    GApplication *app)
+    gboolean assistant,
+    GCallback window_destroyed_cb)
 {
   g_return_if_fail (TP_IS_ACCOUNT_MANAGER (manager));
   g_return_if_fail (!account || TP_IS_ACCOUNT (account));
 
-  if (empathy_accounts_has_non_salut_accounts (manager) ||
+  if ((empathy_accounts_has_non_salut_accounts (manager) && !assistant) ||
           account != NULL)
     {
-      do_show_accounts_ui (manager, account, app);
+      do_show_accounts_ui (manager, account, window_destroyed_cb);
     }
   else
     {
@@ -151,10 +149,7 @@ empathy_accounts_show_accounts_ui (TpAccountManager *manager,
 
       cm_mgr = empathy_connection_managers_dup_singleton ();
 
-      /* Hold the application while preparing cm_mgr */
-      g_application_hold (app);
-
       empathy_connection_managers_prepare_async (cm_mgr,
-          connection_managers_prepare_for_accounts, app);
+          connection_managers_prepare_for_accounts, window_destroyed_cb);
     }
 }
