@@ -54,39 +54,38 @@
 static gboolean only_if_needed = FALSE;
 static gboolean hidden = FALSE;
 static gchar *selected_account_name = NULL;
+static gboolean account_manager_prepared = FALSE;
+static gboolean assistant = FALSE;
 
 static void
-maybe_show_accounts_ui (TpAccountManager *manager,
-    GApplication *app)
+account_prepare_cb (GObject *source_object,
+    GAsyncResult *result,
+    gpointer user_data)
 {
-  if (hidden)
-    return;
+  TpAccountManager *manager = TP_ACCOUNT_MANAGER (user_data);
+  TpAccount *account = TP_ACCOUNT (source_object);
+  GError *error = NULL;
 
-  if (only_if_needed && empathy_accounts_has_non_salut_accounts (manager))
-    return;
-
-  empathy_accounts_show_accounts_ui (manager, NULL, app);
-}
-
-static TpAccount *
-find_account (TpAccountManager *mgr,
-    const gchar *path)
-{
-  GList *accounts, *l;
-  TpAccount *found = NULL;
-
-  accounts = tp_account_manager_get_valid_accounts (mgr);
-  for (l = accounts; l != NULL; l = g_list_next (l))
+  if (!tp_proxy_prepare_finish (account, result, &error))
     {
-      if (!tp_strdiff (tp_proxy_get_object_path (l->data), path))
-        {
-          found = l->data;
-          break;
-        }
+      DEBUG ("Failed to prepare account: %s", error->message);
+      g_error_free (error);
+
+      account = NULL;
     }
 
-  g_list_free (accounts);
-  return found;
+  empathy_accounts_show_accounts_ui (manager, account, assistant,
+      G_CALLBACK (gtk_main_quit));
+}
+
+static void
+maybe_show_accounts_ui (TpAccountManager *manager)
+{
+  if (hidden ||
+      (only_if_needed && empathy_accounts_has_non_salut_accounts (manager)))
+    gtk_main_quit ();
+  else
+    empathy_accounts_show_accounts_ui (manager, NULL, assistant, gtk_main_quit);
 }
 
 static void
@@ -96,19 +95,21 @@ account_manager_ready_for_accounts_cb (GObject *source_object,
 {
   TpAccountManager *manager = TP_ACCOUNT_MANAGER (source_object);
   GError *error = NULL;
-  GApplication *app = G_APPLICATION (user_data);
 
   if (!tp_proxy_prepare_finish (manager, result, &error))
     {
       DEBUG ("Failed to prepare account manager: %s", error->message);
       g_clear_error (&error);
-      goto out;
+      return;
     }
 
+  account_manager_prepared = TRUE;
+
   if (selected_account_name != NULL)
     {
       gchar *account_path;
-      TpAccount *account;
+      TpAccount *account = NULL;
+      TpDBusDaemon *bus;
 
       /* create and prep the corresponding TpAccount so it's fully ready by the
        * time we try to select it in the accounts dialog */
@@ -118,48 +119,49 @@ account_manager_ready_for_accounts_cb (GObject *source_object,
         account_path = g_strdup_printf ("%s%s", TP_ACCOUNT_OBJECT_PATH_BASE,
             selected_account_name);
 
-      account = find_account (manager, account_path);
-
-      if (account != NULL)
+      bus = tp_dbus_daemon_dup (NULL);
+      if ((account = tp_account_new (bus, account_path, &error)))
         {
-          empathy_accounts_show_accounts_ui (manager, account, app);
-          goto out;
+          tp_proxy_prepare_async (account, NULL, account_prepare_cb, manager);
+          g_object_unref (bus);
+          return;
         }
       else
         {
-          DEBUG ("Failed to find account with path %s", account_path);
-
+          DEBUG ("Failed to find account with path %s: %s", account_path,
+              error->message);
           g_clear_error (&error);
 
-          maybe_show_accounts_ui (manager, app);
+          maybe_show_accounts_ui (manager);
         }
 
+      g_object_unref (bus);
       g_free (account_path);
     }
   else
     {
-      maybe_show_accounts_ui (manager, app);
+      maybe_show_accounts_ui (manager);
     }
-
-out:
-  g_application_release (app);
 }
 
 static int
 app_command_line_cb (GApplication *app,
     GApplicationCommandLine *cmdline)
 {
-  TpAccountManager *account_manager;
-
-  account_manager = tp_account_manager_dup ();
-
-  /* Hold the application while preparing the AM */
   g_application_hold (app);
 
-  tp_proxy_prepare_async (account_manager, NULL,
-    account_manager_ready_for_accounts_cb, app);
+  /* if the window is ready, present it; otherwise, it will be presented when
+   * the accounts manager is prepared */
+  if (account_manager_prepared)
+    {
+      TpAccountManager *account_manager;
 
-  g_object_unref (account_manager);
+      account_manager = tp_account_manager_dup ();
+      empathy_accounts_show_accounts_ui (account_manager, NULL, assistant,
+              G_CALLBACK (gtk_main_quit));
+
+      g_object_unref (account_manager);
+    }
 
   return 0;
 }
@@ -190,6 +192,10 @@ local_cmdline (GApplication *app,
         N_("Initially select given account (eg, "
             "gabble/jabber/foo_40example_2eorg0)"),
         N_("<account-id>") },
+      { "assistant", 'a',
+        0, G_OPTION_ARG_NONE, &assistant,
+        N_("Show account assistant"),
+        NULL },
 
       { NULL }
   };
@@ -217,9 +223,12 @@ local_cmdline (GApplication *app,
   return retval;
 }
 
+#define COMMAND_ACCOUNTS_DIALOG 1
+
 int
 main (int argc, char *argv[])
 {
+  TpAccountManager *account_manager;
   GtkApplication *app;
   GObjectClass *app_class;
   gint retval;
@@ -242,11 +251,17 @@ main (int argc, char *argv[])
   app_class = G_OBJECT_GET_CLASS (app);
   G_APPLICATION_CLASS (app_class)->local_command_line = local_cmdline;
 
+  account_manager = tp_account_manager_dup ();
+
+  tp_proxy_prepare_async (account_manager, NULL,
+    account_manager_ready_for_accounts_cb, NULL);
+
   g_signal_connect (app, "command-line", G_CALLBACK (app_command_line_cb),
       NULL);
 
   retval = g_application_run (G_APPLICATION (app), argc, argv);
 
+  g_object_unref (account_manager);
   g_object_unref (app);
 
   return retval;
