@@ -30,14 +30,12 @@
 
 #include <telepathy-farstream/telepathy-farstream.h>
 
-#include <libempathy/empathy-channel-factory.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-tp-contact-factory.h>
 
 #include <libempathy-gtk/empathy-call-utils.h>
 
 #include "empathy-call-handler.h"
-#include "src-marshal.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_VOIP
 #include <libempathy/empathy-debug.h>
@@ -192,13 +190,18 @@ static void
 on_call_state_changed_cb (TpyCallChannel *call,
   TpyCallState state,
   TpyCallFlags flags,
-   const GValueArray *call_state_reason,
+  const GValueArray *call_state_reason,
   GHashTable *call_state_details,
   EmpathyCallHandler *handler)
 {
   EmpathyCallHandlerPriv *priv = handler->priv;
+  gchar *dbus_reason;
+  guint actor, reason;
 
-  g_signal_emit (handler, signals[STATE_CHANGED], 0, state);
+  tp_value_array_unpack ((GValueArray *) call_state_reason, 3,
+      &actor, &reason, &dbus_reason);
+
+  g_signal_emit (handler, signals[STATE_CHANGED], 0, state, dbus_reason);
 
   if (state == TPY_CALL_STATE_ENDED)
     {
@@ -458,56 +461,56 @@ empathy_call_handler_class_init (EmpathyCallHandlerClass *klass)
   signals[CONFERENCE_ADDED] =
     g_signal_new ("conference-added", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-      g_cclosure_marshal_VOID__OBJECT,
+      g_cclosure_marshal_generic,
       G_TYPE_NONE,
       1, FS_TYPE_CONFERENCE);
 
   signals[CONFERENCE_REMOVED] =
     g_signal_new ("conference-removed", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-      g_cclosure_marshal_VOID__OBJECT,
+      g_cclosure_marshal_generic,
       G_TYPE_NONE,
       1, FS_TYPE_CONFERENCE);
 
   signals[SRC_PAD_ADDED] =
     g_signal_new ("src-pad-added", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-      _src_marshal_BOOLEAN__OBJECT_UINT,
+      g_cclosure_marshal_generic,
       G_TYPE_BOOLEAN,
       2, GST_TYPE_PAD, G_TYPE_UINT);
 
   signals[SINK_PAD_ADDED] =
     g_signal_new ("sink-pad-added", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-      _src_marshal_BOOLEAN__OBJECT_UINT,
+      g_cclosure_marshal_generic,
       G_TYPE_BOOLEAN,
       2, GST_TYPE_PAD, G_TYPE_UINT);
 
   signals[SINK_PAD_REMOVED] =
     g_signal_new ("sink-pad-removed", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-      _src_marshal_BOOLEAN__OBJECT_UINT,
+      g_cclosure_marshal_generic,
       G_TYPE_BOOLEAN,
       2, GST_TYPE_PAD, G_TYPE_UINT);
 
   signals[CLOSED] =
     g_signal_new ("closed", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-      g_cclosure_marshal_VOID__VOID,
+      g_cclosure_marshal_generic,
       G_TYPE_NONE,
       0);
 
   signals[CANDIDATES_CHANGED] =
     g_signal_new ("candidates-changed", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-      g_cclosure_marshal_VOID__UINT,
+      g_cclosure_marshal_generic,
       G_TYPE_NONE, 1, G_TYPE_UINT);
 
   signals[STATE_CHANGED] =
     g_signal_new ("state-changed", G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST, 0, NULL, NULL,
-      g_cclosure_marshal_VOID__UINT,
-      G_TYPE_NONE, 1, G_TYPE_UINT);
+      g_cclosure_marshal_generic,
+      G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_STRING);
 }
 
 EmpathyCallHandler *
@@ -944,7 +947,6 @@ empathy_call_handler_start_call (EmpathyCallHandler *handler,
     gint64 timestamp)
 {
   EmpathyCallHandlerPriv *priv = GET_PRIV (handler);
-  EmpathyChannelFactory *channel_factory;
   TpAccountChannelRequest *req;
   TpAccount *account;
   GHashTable *request;
@@ -966,11 +968,6 @@ empathy_call_handler_start_call (EmpathyCallHandler *handler,
 
   req = tp_account_channel_request_new (account, request, timestamp);
 
-  channel_factory = empathy_channel_factory_dup ();
-  tp_account_channel_request_set_channel_factory (req,
-      TP_CLIENT_CHANNEL_FACTORY (channel_factory));
-  g_object_unref (channel_factory);
-
   tp_account_channel_request_create_and_handle_channel_async (req, NULL,
       empathy_call_handler_request_cb, handler);
 
