@@ -1482,8 +1482,7 @@ chat_window_new_message_cb (EmpathyChat       *chat,
 	 *   a) the chatroom's always_urgent property is TRUE
 	 *   b) the message contains our alias
 	 */
-	if (empathy_chat_is_room (chat) ||
-	    empathy_chat_get_remote_contact (chat) == NULL) {
+	if (empathy_chat_is_room (chat)) {
 		TpAccount             *account;
 		const gchar           *room;
 		EmpathyChatroom       *chatroom;
@@ -1866,7 +1865,9 @@ chat_window_drag_data_received (GtkWidget        *widget,
 
 		if (!chat) {
 			empathy_chat_with_contact_id (
-				account, contact_id, empathy_get_current_action_time ());
+				account, contact_id,
+				empathy_get_current_action_time (),
+				NULL, NULL);
 
 			g_strfreev (strv);
 			return;
